[Swift-commit] r6734 - SwiftTutorials/ATPESC_2013-08-06/scripts

yadunandb at ci.uchicago.edu yadunandb at ci.uchicago.edu
Sun Aug 4 01:43:22 CDT 2013


Author: yadunandb
Date: 2013-08-04 01:43:22 -0500 (Sun, 04 Aug 2013)
New Revision: 6734

Modified:
   SwiftTutorials/ATPESC_2013-08-06/scripts/README
   SwiftTutorials/ATPESC_2013-08-06/scripts/start_coaster_workers.sh
Log:

start_coaster_worker now submits workers to the queue on vesta.
Updated readme.



Modified: SwiftTutorials/ATPESC_2013-08-06/scripts/README
===================================================================
--- SwiftTutorials/ATPESC_2013-08-06/scripts/README	2013-08-04 05:45:35 UTC (rev 6733)
+++ SwiftTutorials/ATPESC_2013-08-06/scripts/README	2013-08-04 06:43:22 UTC (rev 6734)
@@ -10,6 +10,9 @@
 $ ./start-coaster-workers.sh
 -----
 When prompted for the password, enter the password for vesta.
-Once the script completes, a  sites.xml file would be generated that could be
-used by swift to connect to the active coaster-service and submit jobs to the
-worker on Vesta.
+Once the script completes, the jobid of the worker submitted via qsub would be
+displayed and a sites.xml file would be generated that could be used by swift 
+to connect to the active coaster-service and submit jobs to the worker on Vesta. 
+
+Note: Allow for a few seconds for the worker submitted to the queue to start. 
+This can be monitored from the coaster-log.
\ No newline at end of file

Modified: SwiftTutorials/ATPESC_2013-08-06/scripts/start_coaster_workers.sh
===================================================================
--- SwiftTutorials/ATPESC_2013-08-06/scripts/start_coaster_workers.sh	2013-08-04 05:45:35 UTC (rev 6733)
+++ SwiftTutorials/ATPESC_2013-08-06/scripts/start_coaster_workers.sh	2013-08-04 06:43:22 UTC (rev 6734)
@@ -1,12 +1,11 @@
 #!/bin/bash
-
-######
+###########
 #start_coaster_workers.sh
 #
 #This script will start a coaster service on Tukey. It will then create 
 #reverse ssh tunnel from Vesta to Tukey and start a worker on the vesta 
 #login node.
 ######
 
 LPORT_F=local_port
 SPORT_F=service_port
@@ -28,7 +27,15 @@
 ssh -f -n -N $REMOTESYS -R $LOCAL_PORT:$LOCALSYS:$LOCAL_PORT
 
 #Start a worker on the remote system
-WORKER_STRING="./worker.pl http://localhost:$LOCAL_PORT 1 . &"
+#WORKER_STRING="./worker.pl http://localhost:$LOCAL_PORT 1 . &"
+
+# Submit a worker to the queue on the remote system
+# -n 1         : ask for 1 node
+# -t 120       : request for a walltime of 2 hours (I do not know the max time)
+# -q default   : submit to default queue
+# --mode script: specify type of submitted job 
+WORKER_STRING="cp /home/wilde/swift/rev/swift-0.94.1/bin/worker.pl ~/ ; \
+qsub -n 1 -t 120 -q default --mode script worker.pl http://localhost:$LOCAL_PORT 1 ."
 ssh -f $REMOTESYS $WORKER_STRING
 
 # Generate the sites.xml file
@@ -1,12 +1,11 @@
 #
 #This script will start a coaster service on Tukey. It will then create 
-#reverse ssh tunnel from Vesta to Tukey and start a worker on the vesta 
-#login node.
-######
+#reverse ssh tunnel from Vesta to Tukey and submits a worker on the vesta 
+#login node via qsub.
+###########
 
 LPORT_F=local_port




More information about the Swift-commit mailing list